@@ -3,7 +3,7 @@
 //OPEX
 istream &std::operator>>(istream &str, field const &params)
 {
-    return reinterpret_cast<Fistream *>(&str)->setField(params);
+    return static_cast<Fistream *>(&str)->setField(params);
 }
 //=
 
@@ -19,7 +19,7 @@ Fistream::Fistream(istream &stream)
 Fistream::Fistream(char const *name, ios::openmode mode)
 :
     istream(new filebuf()),
-    d_filebuf(reinterpret_cast<filebuf *>(rdbuf())),
+    d_filebuf(static_cast<filebuf *>(rdbuf())),
     d_streambuf(d_filebuf.get()),
     d_width(0)
 {
@@ -45,12 +45,12 @@ void Fistream::setBuffer()
 {
     char *buffer = new char[d_width + 1];
 
-    rdbuf(d_streambuf);                     // use istream's buffer to
+    rdbuf(d_streambuf);                         // use istream's buffer to
     buffer[read(buffer, d_width).gcount()] = 0; // read d_width chars,
                                                 // terminated by ascii-Z
     d_iss.str(buffer);
-    delete buffer;
+    delete[] buffer;
 
-    rdbuf(d_iss.rdbuf());                   // switch buffers
+    rdbuf(d_iss.rdbuf());                       // switch buffers
 }
 //=
